Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(2416)

Unified Diff: webrtc/api/objc/RTCVideoSource+Private.h

Issue 1546783002: Move RTCVideoSource to webrtc/api/objc. (Closed) Base URL: https://chromium.googlesource.com/external/webrtc.git@updateRTCMediaSource
Patch Set: Update against master Created 4 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « webrtc/api/objc/RTCVideoSource.mm ('k') | no next file » | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: webrtc/api/objc/RTCVideoSource+Private.h
diff --git a/webrtc/api/objc/RTCMediaSource+Private.h b/webrtc/api/objc/RTCVideoSource+Private.h
similarity index 66%
rename from webrtc/api/objc/RTCMediaSource+Private.h
rename to webrtc/api/objc/RTCVideoSource+Private.h
index fcbaad8e4587a6d426dd51eb0a0e0b945f5c2b19..2300848610b6dd9b2fbd3c8b50b20bd350a1cb58 100644
--- a/webrtc/api/objc/RTCMediaSource+Private.h
+++ b/webrtc/api/objc/RTCVideoSource+Private.h
@@ -8,24 +8,24 @@
* be found in the AUTHORS file in the root of the source tree.
*/
-#import "RTCMediaSource.h"
+#import "RTCVideoSource.h"
-#include "talk/app/webrtc/mediastreaminterface.h"
+#include "talk/app/webrtc/videosourceinterface.h"
NS_ASSUME_NONNULL_BEGIN
-@interface RTCMediaSource ()
+@interface RTCVideoSource ()
/**
* The MediaSourceInterface object passed to this RTCMediaSource during
* construction.
*/
@property(nonatomic, readonly)
- rtc::scoped_refptr<webrtc::MediaSourceInterface> nativeMediaSource;
+ rtc::scoped_refptr<webrtc::VideoSourceInterface> nativeVideoSource;
-/** Initialize an RTCMediaSource from a native MediaSourceInterface. */
-- (instancetype)initWithNativeMediaSource:
- (rtc::scoped_refptr<webrtc::MediaSourceInterface>)nativeMediaSource
+/** Initialize an RTCVideoSource from a native VideoSourceInterface. */
+- (instancetype)initWithNativeVideoSource:
+ (rtc::scoped_refptr<webrtc::VideoSourceInterface>)nativeVideoSource
NS_DESIGNATED_INITIALIZER;
+ (webrtc::MediaSourceInterface::SourceState)nativeSourceStateForState:
« no previous file with comments | « webrtc/api/objc/RTCVideoSource.mm ('k') | no next file » | no next file with comments »

Powered by Google App Engine
@@ -8,24 +8,24 @@
/**
- * The MediaSourceInterface object passed to this RTCMediaSource during
+ * The VideoSourceInterface object passed to this RTCVideoSource during
* construction.
*/
This is Rietveld 408576698